@@ -3,7 +3,7 @@ import json
 import time
 import os
 
-import quantum_lab.resources
+import quantum_lab.resources as res
 
 class quantum_lab():
 
@@ -17,7 +17,7 @@ class quantum_lab():
         self.resourceId = resourceId
         # self.filePath = filePath
         self.volumeName = self.getDirpath(volumeName)
-        self.resourceName = getResourceName(self.resourceId)
+        self.resourceName = res.getResourceName(resourceId)
         self.url = "http://job-management.qcc.svc.cluster.local"
 
         if not isinstance(self.volumeName, str):
